@@ -42,7 +42,7 @@ from PyQt5.QtWidgets import (
     QVBoxLayout,
     QWidget,
 )
-
+from abstract_utilities import is_number
 # -----------------------------------------------------------------------------
 #  helper heuristics -----------------------------------------------------------
 # -----------------------------------------------------------------------------
@@ -65,6 +65,9 @@ def looks_unsaved(title: str) -> bool:
     )
 
 
+
+
+    
 # -----------------------------------------------------------------------------
 #  main application ------------------------------------------------------------
 # -----------------------------------------------------------------------------
@@ -104,17 +107,18 @@ class WindowManagerApp(QMainWindow):
                 name, w, h, x, y = m.groups()
                 self.monitors.append((name, int(x), int(y), int(w), int(h)))
         return self.monitors
-
+    
     def get_windows(self) -> List[Tuple[str, str, str, str, str]]:
         """Return [(id, pid, title, monitor, type), …]"""
         self.windows.clear()
         mons = self.get_monitors()
         out = self.run_command("wmctrl -l -p -G")
+        
         for line in out.splitlines():
             parts = line.split()
             if len(parts) < 8:
                 continue
-            win_id, desktop, pid, x, y, w, h = parts[:7]
+            win_id, desktop, pid, x, y, w, h= parts[:7]
             title = " ".join(parts[8:])
             x, y = int(x), int(y)
             monitor = "Unknown"
@@ -289,12 +293,124 @@ class WindowManagerApp(QMainWindow):
         self.statusBar().showMessage(f"Opened {base}", 3000)
 
 
+   
 # -----------------------------------------------------------------------------
 #  run ------------------------------------------------------------------------
 # -----------------------------------------------------------------------------
 
-def start_window_info_gui():
+def parse_window_info(line):
+    parts = line.split()
+    window_js = {}
+    keys = ['win_id', 'desktop', 'pid', 'x', 'y', 'w', 'h', 'extra']
+    last_key=keys[0]
+    for i,part in enumerate(parts):
+        if last_key != "extra":
+            last_key = keys[i]
+            
+        if last_key == "extra":
+            found = False
+            if last_key not in window_js:
+                window_js[last_key] = []
+            if window_js.get('location') == None:
+                if os.path.exists(part):
+                    found = True
+                    window_js['location']=part
+                    basename = os.path.basename(part)
+                    window_js['basename'] = basename
+                    if window_js.get('name') == None and window_js.get('extra'):
+                        extra = window_js.get('extra')
+                        name= ' '.join(extra)
+                        window_js['name'] = name
+                        window_js['extra'] = []
+            if found == False:
+                window_js[last_key].append(part)
+        else:
+          window_js[last_key]=part 
+    x = window_js.get('x')
+    y = window_js.get('y')
+    if is_number(x) and is_number(y):
+        window_js["monitor"] = get_monitor(x,y)
+  
+    return window_js
+def get_window_mgr():
     app = QApplication(sys.argv)
-    win = WindowManagerApp(); win.show()
-    sys.exit(app.exec_())
-start_window_info_gui()
+    window_mgr = WindowManagerApp()
+    return window_mgr
+def get_window_info():
+    window_mgr = get_window_mgr()
+    return window_mgr.run_command("wmctrl -l -p -G")
+def get_active_pid(win_id):
+    window_mgr = get_window_mgr()
+    return window_mgr.run_command(f"xdotool windowactivate {win_id}")
+def get_monitors():
+    window_mgr = get_window_mgr()
+    return window_mgr.get_monitors()
+def both_exist(path,winbase):
+    if path and winbase:
+        path = str(path)
+        winbase = str(winbase)
+        if os.path.exists(path) and os.path.exists(winbase):
+            return True
+    return False
+def resolve_path_file(path,winbase=None,winpath=None):
+    if winpath ==None and winbase==None:
+        return False
+    if winpath ==None and winbase:
+        basename = os.path.basename(path).lower()
+        winbase = winbase.lower()
+        return basenam == winbase
+    if winpath and winbase ==None:
+        winbase = os.path.basename(winpath).lower()
+    if not both_exist(winpath,path):
+        return False
+         
+    basename = os.path.basename(path)
+    if winbase.lower() == basename.lower():
+        return True
+    if os.path.isdir(winpath):
+        if [base.lower() for base in os.listdir(winpath) if base and base == basename.lower()]:
+            return True
+    return False
+
+def verify_file(line,filepath):
+    window_js = parse_window_info(line)
+    base = os.path.basename(file_path).lower()
+    winpath = window_js.get('location')
+    name = window_js.get('name')
+    winbase = window_js.get('basename',name)
+    
+    if resolve_path_file(filepath,winbase=winbase,winpath=winpath):
+        return window_js
+def get_win_id_from_path(filepath):
+    window_info = get_window_info()
+    
+    for line in window_info.split('\n'):
+        window_js = verify_file(line,filepath)
+        if window_js:
+            return window_js
+def get_monitor(x,y):
+    mons = get_monitors()
+    x, y = int(x), int(y)
+    monitor = "Unknown"
+    for name, mx, my, mw, mh in mons:
+        if mx <= x < mx + mw and my <= y < my + mh:
+            monitor = name
+            break
+
+    return monitor
+def parse_window_infos():
+    out = get_window_info()
+    pieces = out.splitlines()
+    for i,line in enumerate(pieces):
+        try:
+            window_js = parse_window_info(line)
+            pieces.append(window_js)
+        except Exception as e:
+            print(f"{e}")
+    return pieces
+def get_file_attrib(file_path):
+    window_info = get_window_info()
+    lines = window_info.split('\n')
+    get_win_id_from_path(file_path)
+file_path = '/home/computron/Documents/pythonTools/modules/abstract_ai/src/abstract_ai/gpt_classes/gpt_manager/window_section/window_management.py'
+input(get_win_id_from_path(file_path))
